# opentoken-python

[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-v2.0%20adopted-ff69b4.svg)](code-of-conduct.md)

OpenToken support for Python.

A Python implementation of generating and parsing OpenTokens. Much of this implementation is borrowed from [node-opentoken](https://github.com/73rhodes/node-opentoken).

https://tools.ietf.org/html/draft-smith-opentoken-02

## Contributing

Feel free to dive in! [Open an issue](https://github.com/yoonjesung/opentoken-python/issues/new) or submit PRs.
